@@ -1,20 +1,20 @@
 /* Schedwi
    Copyright (C) 2007 Herve Quatremain
      
-   This program is free software; you can redistribute it and/or modify
+   This file is part of Schedwi.
+
+   Schedwi is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
-     
-   This program is distributed in the hope that it will be useful,
+
+   Schedwi is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU Library General Public License for more details.
-     
+   GNU General Public License for more details.
+
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /* net_utils_init.h -- Initialize the network (mainly for SSL) */
@@ -30,7 +30,7 @@ extern "C" {
 #endif
 
 extern int net_init OF((const char *client_crt, const char *client_key,
-			const char *server_crt));
+			const char *server_crt, char quick_random));
 extern int net_init_server OF(());
 extern void net_free OF(());
 extern char ssl_enabled OF(());
