@@ -1,20 +1,20 @@
 /* Schedwi
    Copyright (C) 2007 Herve Quatremain
+     
+   This file is part of Schedwi.
 
-   This program is free software; you can redistribute it and/or modify
+   Schedwi is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
 
-   This program is distributed in the hope that it will be useful,
+   Schedwi is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU Library General Public License for more details.
+   GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /* net_utils_ssl.c -- Useful network functions (socket connection with SSL) */
@@ -65,6 +65,7 @@ extern int errno;
 
 #include <gnutls/gnutls.h>
 #include <gnutls/x509.h>
+#include <gcrypt.h>
 
 #include <lib_functions.h>
 #include <lwc_log.h>
@@ -162,7 +163,7 @@ _("SSL: Failed to generate the parameters for the RSA algorithms: %s"),
  */
 int
 net_init_ssl (	const char *clnt_crt_file, const char *clnt_key_file,
-		const char *server_crt)
+		const char *server_crt, char quick_random)
 {
 	int ret;
 
@@ -171,6 +172,11 @@ net_init_ssl (	const char *clnt_crt_file, const char *clnt_key_file,
 		&& server_crt != NULL);
 #endif
 
+	/* Fast random mode (less secure) */
+	if (quick_random != 0) {
+		gcry_control (GCRYCTL_ENABLE_QUICK_RANDOM, 0);
+	}
+
 	if (cerdentials_set != 0) {
 		gnutls_certificate_free_credentials (x509_cred);
 		cerdentials_set = 0;
